@@ -2,6 +2,6 @@ var node_itk = require('../index.js');
 
 var image = new node_itk.NodeImage('uchar',3);
 
-image.Read('uchar',2, 'Desert.jpg');
+image.Read('uchar',2, './Data/Desert.jpg');
 
 console.log(image.GetSize())
\ No newline at end of file
